@@ -18,7 +18,7 @@ class DataFetcher:
         Returns:
             dict: Dictionary of official OLI tags
         """
-        url = "https://raw.githubusercontent.com/openlabelsinitiative/OLI/refs/heads/main/1_data_model/tags/tag_definitions.yml"
+        url = "https://raw.githubusercontent.com/openlabelsinitiative/OLI/refs/heads/main/1_label_schema/tags/tag_definitions.yml"
         response = requests.get(url)
         if response.status_code == 200:
             y = yaml.safe_load(response.text)
@@ -36,16 +36,29 @@ class DataFetcher:
         """
         value_sets = {}
 
-        # value sets from self.oli.tag_definitions (must be a list)
-        additional_value_sets = {i['tag_id']: i['value_set'] for i in self.oli.tag_definitions.values() if 'value_set' in i}
-        for tag_id, value_set in additional_value_sets.items():
-            if isinstance(value_set, list):
-                # convert all string values to lowercase and keep the rest as is
-                value_set = [i.lower() if isinstance(i, str) else i for i in value_set]
-                value_sets[tag_id] = value_set
+        # Extract value sets from tag definitions (must be a list)
+        for tag_def in self.oli.tag_definitions.values():
+            if 'schema' not in tag_def:
+                continue
+            
+            schema = tag_def['schema']
+            tag_id = tag_def['tag_id']
+            value_set = None
+            
+            # Get enum from direct schema or array items
+            if 'enum' in schema:
+                value_set = schema['enum']
+            elif (schema.get('type') == 'array' and 
+                'items' in schema and 
+                'enum' in schema['items']):
+                value_set = schema['items']['enum']
+            
+            # Process and add to value_sets
+            if value_set and isinstance(value_set, list):
+                value_sets[tag_id] = [i.lower() if isinstance(i, str) else i for i in value_set]
 
         # value set for owner_project
-        url = "https://api.growthepie.xyz/v1/labels/projects.json" 
+        url = "https://api.growthepie.com/v1/labels/projects.json" 
         response = requests.get(url)
         if response.status_code == 200:
             y = yaml.safe_load(response.text)
@@ -55,7 +68,7 @@ class DataFetcher:
             raise Exception(f"Failed to fetch owner_project value set from grwothepie projects api: {response.status_code} - {response.text}")
 
         # value set for usage_category
-        url = "https://raw.githubusercontent.com/openlabelsinitiative/OLI/refs/heads/main/1_data_model/tags/valuesets/usage_category.yml"
+        url = "https://raw.githubusercontent.com/openlabelsinitiative/OLI/refs/heads/main/1_label_schema/tags/valuesets/usage_category.yml"
         response = requests.get(url)
         if response.status_code == 200:
             y = yaml.safe_load(response.text)
@@ -76,7 +89,7 @@ class DataFetcher:
         Returns:
             str: Path to the downloaded Parquet file
         """
-        url = "https://api.growthepie.xyz/v1/oli/labels_raw.parquet"
+        url = "https://api.growthepie.com/v1/oli/labels_raw.parquet"
         
         response = requests.get(url, stream=True)
         if response.status_code == 200:
@@ -98,7 +111,7 @@ class DataFetcher:
         Returns:
             str: Path to the downloaded Parquet file
         """
-        url = "https://api.growthepie.xyz/v1/oli/labels_decoded.parquet"
+        url = "https://api.growthepie.com/v1/oli/labels_decoded.parquet"
         
         response = requests.get(url, stream=True)
         if response.status_code == 200:
